/**
 * This export is a variant of the quickjs WASM library:
 * ### [@jitl/quickjs-node-esm-release-asyncify-wasm](https://github.com/justjake/quickjs-emscripten/blob/main/doc/packages/@jitl/quickjs-node-esm-release-asyncify-wasm/README.md)
 *
 * Node.js ESModule
 *
 * | Variable            |    Setting                     |    Description    |
 * | --                  | --                             | --                |
 * | releaseMode         | release | Optimized for performance; use when building/deploying your application. |
 * | syncMode            | asyncify | Build run through the ASYNCIFY WebAssembly transform. Larger and slower. Allows synchronous calls from the WASM runtime to async functions on the host. The extra magic makes this variant slower than sync variants. Note that both variants support regular async functions. Only adopt ASYNCIFY if you need to! |
 * | moduleSystem        | esm | This variant exports an ESModule, which is standardized for browsers and more modern browser-like environments. It cannot be imported from CommonJS without shenanigans. |
 * | emscriptenInclusion | wasm | Has a separate .wasm file. May offer better caching in your browser, and reduces the size of your JS bundle. If you have issues, try a 'singlefile' variant. |
 *
 */
declare const variant: {
    readonly type: "async";
    readonly importFFI: () => Promise<typeof import("./ffi.js").QuickJSAsyncFFI | (new (module: import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule) => import("@jitl/quickjs-ffi-types").QuickJSAsyncFFI)>;
    readonly importModuleLoader: () => Promise<import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule> | {
        default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule>;
    } | {
        default: {
            default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule>;
        };
    }>;
};
export default variant;
